Skip to content

erfcf

产品支持情况

  • Ascend 950PR/Ascend 950DT:支持
  • Atlas A3 训练系列产品/Atlas A3 推理系列产品:不支持
  • Atlas A2 训练系列产品/Atlas A2 推理系列产品:不支持
  • Atlas 200I/500 A2 推理产品:不支持
  • Atlas 推理系列产品AI Core:不支持
  • Atlas 推理系列产品Vector Core:不支持
  • Atlas 训练系列产品:不支持

功能说明

获取输入数据的互补误差函数值。

函数原型

C++
inline float erfcf(float x)

参数说明

表1 函数形参说明

参数名输入/输出描述
x输入源操作数。

返回值说明

  • 当x为nan时,返回值为nan。
  • 当x为inf时,返回值为0。
  • 当x为-inf时,返回值为2。

约束说明

针对Ascend 950PR/Ascend 950DT,本接口不支持Subnormal场景:本接口内部实现使用到了exp2f,由于exp2f不支持Subnormal场景,在极少数场景下内部指数计算结果为Subnormal数据,导致本接口最终结果为0。

需要包含的头文件

使用该接口需要包含"simt_api/math_functions.h"头文件。

C++
#include "simt_api/math_functions.h"

调用示例

  • SIMT编程场景:

    C++
    __global__ __launch_bounds__(256) void compute_erfcf(float *result, const float *x, uint32_t count)
    {
        const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x;
        if (idx >= count) {
            return;
        }
        result[idx] = erfcf(x[idx]);
    }
    
  • SIMD与SIMT混合编程场景:

    C++
    __simt_vf__ __launch_bounds__(256) inline void compute_erfcf_vf(__gm__ float *result, __gm__ const float *x, uint32_t count)
    {
        const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x;
        if (idx >= count) {
            return;
        }
        result[idx] = erfcf(x[idx]);
    }
    
    __global__ __vector__ void run_erfcf(__gm__ float *result, __gm__ const float *x, uint32_t count)
    {
        asc_vf_call<compute_erfcf_vf>(dim3(256), result, x, count);
    }
    

输入输出示例如下:

Text
x:0.25, 0.75, 1.25, 1.75
result: 0.7236736 0.2888444 0.07709987 0.01332833

免责声明:本站内容由 asc-devkit 仓 master 分支自动编译生成,属于持续开发版本,可能存在缺陷,仅供预览与参考。如需稳定及商用资料,请查阅官方 昇腾社区